Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExchangeRates ¶
type ExchangeRates struct {
// contains filtered or unexported fields
}
func (*ExchangeRates) MonitorRates ¶
func (e *ExchangeRates) MonitorRates(interval time.Duration) chan struct{}
MonitorRates checks the rates in the ECB API every interval and sends a message to the returned channel when there are changes
Note: the ECB API only returns data once a day, this function only simulates the changes in rates for demonstration purposes
Click to show internal directories.
Click to hide internal directories.